@@ -10,10 +10,11 @@ import paramiko
 import tornado.web
 
 from tornado.ioloop import IOLoop
-from tornado.util import basestring_type
 from webssh.worker import Worker, recycle_worker, workers
-from webssh.utils import (is_valid_ipv4_address, is_valid_ipv6_address,
-                          is_valid_port)
+from webssh.utils import (
+    is_valid_ipv4_address, is_valid_ipv6_address, is_valid_port,
+    is_valid_hostname, to_bytes, to_str, UnicodeType
+)
 
 try:
     from concurrent.futures import Future
@@ -70,7 +71,7 @@ class IndexHandler(MixinHandler, tornado.web.RequestHandler):
             data = self.request.files.get('privatekey')[0]['body']
         except TypeError:
             return
-        return data.decode('utf-8')
+        return to_str(data)
 
     @classmethod
     def get_specific_pkey(cls, pkeycls, privatekey, password):
@@ -87,7 +88,7 @@ class IndexHandler(MixinHandler, tornado.web.RequestHandler):
 
     @classmethod
     def get_pkey_obj(cls, privatekey, password):
-        password = password.encode('utf-8') if password else None
+        password = to_bytes(password)
 
         pkey = cls.get_specific_pkey(paramiko.RSAKey, privatekey, password)\
             or cls.get_specific_pkey(paramiko.DSSKey, privatekey, password)\
@@ -99,6 +100,13 @@ class IndexHandler(MixinHandler, tornado.web.RequestHandler):
                              'wrong password for decrypting the private key.')
         return pkey
 
+    def get_hostname(self):
+        value = self.get_value('hostname')
+        if not (is_valid_hostname(value) | is_valid_ipv4_address(value) |
+                is_valid_ipv6_address(value)):
+            raise ValueError('Invalid hostname {}'.format(value))
+        return value
+
     def get_port(self):
         value = self.get_value('port')
         try:
@@ -114,11 +122,11 @@ class IndexHandler(MixinHandler, tornado.web.RequestHandler):
     def get_value(self, name):
         value = self.get_argument(name)
         if not value:
-            raise ValueError('Empty {}'.format(name))
+            raise ValueError('The {} field is required'.format(name))
         return value
 
     def get_args(self):
-        hostname = self.get_value('hostname')
+        hostname = self.get_hostname()
         port = self.get_port()
         username = self.get_value('username')
         password = self.get_argument('password')
@@ -138,8 +146,8 @@ class IndexHandler(MixinHandler, tornado.web.RequestHandler):
         except paramiko.SSHException:
             result = None
         else:
-            data = stdout.read().decode('utf-8')
-            result = parse_encoding(data)
+            data = stdout.read()
+            result = parse_encoding(to_str(data))
 
         return result if result else 'utf-8'
 
@@ -247,7 +255,7 @@ class WsockHandler(MixinHandler, tornado.websocket.WebSocketHandler):
                 pass
 
         data = msg.get('data')
-        if data and isinstance(data, basestring_type):
+        if data and isinstance(data, UnicodeType):
             worker.data_to_dst.append(data)
             worker.on_write()
 
